@@ -16,7 +16,6 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
-#include "config.h"
 
 #include "common/asserts.h"
 #include "common/filesystembase.h"
@@ -38,6 +37,7 @@
 #include <QSysInfo>
 #include <QTextStream>
 #include <QThread>
+#include <QTimeZone>
 #include <QUrl>
 
 #ifdef Q_OS_UNIX
@@ -45,13 +45,21 @@
 #include <sys/types.h>
 #include <unistd.h>
 #endif
+#ifdef Q_OS_WIN
+#include <qt_windows.h>
+#endif
 
 #include <cstring>
 #include <math.h>
 #include <stdarg.h>
 
 using namespace std::chrono;
-
+namespace {
+auto RFC1123PatternC()
+{
+    return QStringLiteral("ddd, dd MMM yyyy HH:mm:ss 'GMT'");
+}
+}
 namespace OCC {
 
 Q_LOGGING_CATEGORY(lcUtility, "sync.utility")
@@ -180,7 +188,7 @@ qint64 Utility::freeDiskSpace(const QString &path)
 QString Utility::compactFormatDouble(double value, int prec, const QString &unit)
 {
     QLocale locale = QLocale::system();
-    QChar decPoint = locale.decimalPoint();
+    const QString decPoint = locale.decimalPoint();
     QString str = locale.toString(value, 'f', prec);
     while (str.endsWith(QLatin1Char('0')) || str.endsWith(decPoint)) {
         if (str.endsWith(decPoint)) {
@@ -357,33 +365,6 @@ void Utility::crash()
     *a = 1;
 }
 
-// read the output of the owncloud --version command from the owncloud
-// version that is on disk. This works for most versions of the client,
-// because clients that do not yet know the --version flag return the
-// version in the first line of the help output :-)
-//
-// This version only delivers output on linux, as Mac and Win get their
-// restarting from the installer.
-QByteArray Utility::versionOfInstalledBinary(const QString &command)
-{
-    QString binary(command);
-    if (binary.isEmpty()) {
-        binary = qApp->arguments()[0];
-    }
-    QStringList params;
-    params << QStringLiteral("--version");
-    QProcess process;
-    process.start(binary, params);
-    process.waitForFinished(); // sets current thread to sleep and waits for pingProcess end
-    QByteArray re = process.readAllStandardOutput();
-    qCDebug(lcUtility) << Q_FUNC_INFO << re;
-    int newline = re.indexOf('\n');
-    if (newline > 0) {
-        re.truncate(newline);
-    }
-    return re.trimmed();
-}
-
 QString Utility::timeAgoInWords(const QDateTime &dt, const QDateTime &from)
 {
     QDateTime now = QDateTime::currentDateTimeUtc();
@@ -482,6 +463,16 @@ void Utility::sortFilenames(QStringList &fileNames)
     std::sort(fileNames.begin(), fileNames.end(), collator);
 }
 
+QString Utility::concatUrlPathItems(QStringList &&items, const QLatin1Char delimiter)
+{
+    for (QString &item : items) {
+        while (item.endsWith(QLatin1Char('/'))) {
+            item.chop(1);
+        }
+    }
+    return items.join(delimiter);
+}
+
 QUrl Utility::concatUrlPath(const QUrl &url, const QString &concatPath,
     const QUrlQuery &queryItems)
 {
@@ -542,7 +533,7 @@ QString Utility::makeConflictFileName(
     return conflictFileName;
 }
 
-bool Utility::isConflictFile(const QStringRef &name)
+bool Utility::isConflictFile(QStringView name)
 {
     auto bname = name.mid(name.lastIndexOf(QLatin1Char('/')) + 1);
 
@@ -649,6 +640,22 @@ bool Utility::runningInAppImage()
 #endif
 }
 
+QDateTime Utility::parseRFC1123Date(const QString &date)
+{
+    if (!date.isEmpty()) {
+        auto out = QDateTime::fromString(date, RFC1123PatternC());
+        Q_ASSERT(out.isValid());
+        out.setTimeZone(QTimeZone::utc());
+        return out;
+    }
+    return {};
+}
+
+QString Utility::formatRFC1123Date(const QDateTime &date)
+{
+    return date.toUTC().toString(RFC1123PatternC());
+}
+
 } // namespace OCC
 
 QDebug operator<<(QDebug debug, nanoseconds in)
