@@ -249,9 +249,16 @@ void OAuth::startAuthentication()
     qCDebug(lcOauth) << "starting authentication";
 
     // Listen on the socket to get a port which will be used in the redirect_uri
-    if (!_server.listen(QHostAddress::LocalHost)) {
+
+    for (const auto port : Theme::instance()->oauthPorts()) {
+        if (_server.listen(QHostAddress::LocalHost, port)) {
+            break;
+        }
+        qCDebug(lcOauth) << "Creating local server Port:" << port << "failed. Error:" << _server.errorString();
+    }
+    if (!_server.isListening()) {
         qCDebug(lcOauth) << "server is not listening";
-        emit result(NotSupported, QString());
+        emit result(Error, {});
         return;
     }
 
@@ -425,23 +432,26 @@ void OAuth::finalize(const QPointer<QTcpSocket> &socket, const QString &accessTo
     emit result(LoggedIn, accessToken, refreshToken);
 }
 
-QNetworkReply *OAuth::postTokenRequest(const QList<QPair<QString, QString>> &queryItems)
+QNetworkReply *OAuth::postTokenRequest(QUrlQuery &&queryItems)
 {
     const QUrl requestTokenUrl = _tokenEndpoint.isEmpty() ? Utility::concatUrlPath(_serverUrl, QStringLiteral("/index.php/apps/oauth2/api/v1/token")) : _tokenEndpoint;
     QNetworkRequest req;
     req.setTransferTimeout(defaultTimeoutMs());
-    const QByteArray basicAuth = QStringLiteral("%1:%2").arg(_clientId, _clientSecret).toUtf8().toBase64();
-    req.setRawHeader("Authorization", "Basic " + basicAuth);
+    switch (_endpointAuthMethod) {
+    case TokenEndpointAuthMethods::client_secret_basic:
+        req.setRawHeader("Authorization", "Basic " + QStringLiteral("%1:%2").arg(_clientId, _clientSecret).toUtf8().toBase64());
+        break;
+    case TokenEndpointAuthMethods::client_secret_post:
+        queryItems.addQueryItem(QStringLiteral("client_id"), _clientId);
+        queryItems.addQueryItem(QStringLiteral("client_secret"), _clientSecret);
+        break;
+    }
     req.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded; charset=UTF-8"));
     req.setAttribute(HttpCredentials::DontAddCredentialsAttribute, true);
 
-    QUrlQuery arguments;
-    arguments.setQueryItems(QList<QPair<QString, QString>> { { QStringLiteral("client_id"), _clientId },
-                                { QStringLiteral("client_secret"), _clientSecret },
-                                { QStringLiteral("scope"), Theme::instance()->openIdConnectScopes() } }
-        << queryItems);
+    queryItems.addQueryItem(QStringLiteral("scope"), Theme::instance()->openIdConnectScopes());
     req.setUrl(requestTokenUrl);
-    return _networkAccessManager->post(req, arguments.toString(QUrl::FullyEncoded).toUtf8());
+    return _networkAccessManager->post(req, queryItems.toString(QUrl::FullyEncoded).toUtf8());
 }
 
 QByteArray OAuth::generateRandomString(size_t size) const
@@ -484,7 +494,7 @@ QUrl OAuth::authorisationLink() const
 
 void OAuth::saveDynamicRegistrationDataForAccount(const OCC::AccountPtr &accountPtr, const QVariantMap &dynamicRegistrationData)
 {
-    auto credentialsJob = accountPtr->credentialManager()->set(dynamicRegistrationDataC(), dynamicRegistrationData);
+    accountPtr->credentialManager()->set(dynamicRegistrationDataC(), dynamicRegistrationData);
 }
 
 void OAuth::fetchWellKnown()
@@ -525,6 +535,16 @@ void OAuth::fetchWellKnown()
                 _tokenEndpoint = QUrl::fromEncoded(data[QStringLiteral("token_endpoint")].toString().toUtf8());
                 _registrationEndpoint = QUrl::fromEncoded(data[QStringLiteral("registration_endpoint")].toString().toUtf8());
                 _redirectUrl = QStringLiteral("http://127.0.0.1");
+
+                const auto authMethods = data.value(QStringLiteral("token_endpoint_auth_methods_supported")).toArray();
+                if (authMethods.contains(QStringLiteral("client_secret_basic"))) {
+                    _endpointAuthMethod = TokenEndpointAuthMethods::client_secret_basic;
+                } else if (authMethods.contains(QStringLiteral("client_secret_post"))) {
+                    _endpointAuthMethod = TokenEndpointAuthMethods::client_secret_post;
+                } else {
+                    OC_ASSERT_X(false, qPrintable(QStringLiteral("Unsupported token_endpoint_auth_methods_supported: %1").arg(QDebug::toString(authMethods))));
+                }
+
                 qCDebug(lcOauth) << "parsing .well-known reply successful, auth endpoint" << _authEndpoint
                                  << "and token endpoint" << _tokenEndpoint
                                  << "and registration endpoint" << _registrationEndpoint;
@@ -568,10 +588,7 @@ void OAuth::openBrowser()
 
     if (!isUrlValid(authorisationLink())) {
         qCWarning(lcOauth) << "URL validation failed";
-        QMetaObject::invokeMethod(qApp, "slotShowGuiMessage", Qt::QueuedConnection,
-            Q_ARG(QString, tr("Oauth2 Error")),
-            Q_ARG(QString, tr("Oauth2 authentication requires a secured connection.")));
-        emit result(Error, QString());
+        Q_EMIT result(ErrorInsecureUrl, QString());
         return;
     }
 
@@ -664,12 +681,12 @@ void AccountBasedOAuth::refreshAuthentication(const QString &refreshToken)
                 QString accessToken;
                 QString newRefreshToken = refreshToken;
                 // https://developer.okta.com/docs/reference/api/oidc/#response-properties-2
-                const QString error = data.value(QStringLiteral("error")).toString();
-                if (!error.isEmpty()) {
-                    if (error == QLatin1String("invalid_grant") || error == QLatin1String("invalid_request")) {
+                const QString errorString = data.value(QStringLiteral("error")).toString();
+                if (!errorString.isEmpty()) {
+                    if (errorString == QLatin1String("invalid_grant") || errorString == QLatin1String("invalid_request")) {
                         newRefreshToken.clear();
                     } else {
-                        qCWarning(lcOauth) << "Error while refreshing the token:" << error << data.value(QStringLiteral("error_description")).toString();
+                        qCWarning(lcOauth) << "Error while refreshing the token:" << errorString << data.value(QStringLiteral("error_description")).toString();
                     }
                 } else if (reply->error() != QNetworkReply::NoError) {
                     qCWarning(lcOauth) << "Error while refreshing the token:" << reply->error() << ":" << reply->errorString() << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
