@@ -14,7 +14,6 @@
 
 #include "propagatedownload.h"
 #include "account.h"
-#include "config.h"
 #include "filesystem.h"
 #include "networkjobs.h"
 #include "owncloudpropagator_p.h"
@@ -416,16 +415,16 @@ void PropagateDownloadFile::start()
     if (propagator()->_abortRequested)
         return;
 
-    qCDebug(lcPropagateDownload) << _item->_file << propagator()->_activeJobList.count();
     _stopwatch.start();
 
     auto &syncOptions = propagator()->syncOptions();
     auto &vfs = syncOptions._vfs;
 
+
+    const QString fsPath = propagator()->fullLocalPath(_item->_file);
     // For virtual files just dehydrate or create the file and be done
     if (_item->_type == ItemTypeVirtualFileDehydration) {
-        const QString fsPath = propagator()->fullLocalPath(_item->_file);
-        if (FileSystem::fileChanged(fsPath, _item->_previousSize, _item->_previousModtime)) {
+        if (FileSystem::fileChanged(QFileInfo{fsPath}, _item->_previousSize, _item->_previousModtime)) {
             propagator()->_anotherSyncNeeded = true;
             done(SyncFileItem::SoftError, tr("File has changed since discovery"));
             return;
@@ -443,21 +442,6 @@ void PropagateDownloadFile::start()
         qCWarning(lcPropagateDownload) << "ignored virtual file type of" << _item->_file;
         _item->_type = ItemTypeFile;
     }
-    if (_item->_type == ItemTypeVirtualFile) {
-        qCDebug(lcPropagateDownload) << "creating virtual file" << _item->_file;
-        // do a klaas' case clash check.
-        if (auto clash = propagator()->localFileNameClash(_item->_file)) {
-            done(SyncFileItem::NormalError, tr("File %1 can not be downloaded because of a local file name clash with %2!").arg(QDir::toNativeSeparators(_item->_file), QDir::toNativeSeparators(clash.get())));
-            return;
-        }
-        auto r = vfs->createPlaceholder(*_item);
-        if (!r) {
-            done(SyncFileItem::NormalError, r.error());
-            return;
-        }
-        updateMetadata(false);
-        return;
-    }
 
     if (_deleteExisting) {
         deleteExistingFolder();
@@ -468,6 +452,30 @@ void PropagateDownloadFile::start()
         }
     }
 
+    if (_item->_type == ItemTypeVirtualFile) {
+        qCDebug(lcPropagateDownload) << "creating virtual file" << _item;
+        // do a klaas' case clash check.
+        if (auto clash = propagator()->localFileNameClash(_item->_file)) {
+            done(SyncFileItem::NormalError, tr("File %1 can not be downloaded because of a local file name clash with %2!").arg(QDir::toNativeSeparators(_item->_file), QDir::toNativeSeparators(clash.get())));
+            return;
+        }
+        const bool isConflict = _item->instruction() == CSYNC_INSTRUCTION_CONFLICT && QFileInfo(fsPath).isDir();
+        if (isConflict) {
+            QString error;
+            if (!propagator()->createConflict(_item, _associatedComposite, &error)) {
+                done(SyncFileItem::SoftError, error);
+                return;
+            }
+        }
+        auto r = vfs->createPlaceholder(*_item);
+        if (!r) {
+            done(SyncFileItem::NormalError, r.error());
+            return;
+        }
+        updateMetadata(isConflict);
+        return;
+    }
+
     // If we have a conflict where size of the file is unchanged,
     // compare the remote checksum to the local one.
     // Maybe it's not a real conflict and no download is necessary!
@@ -485,11 +493,8 @@ void PropagateDownloadFile::start()
         return true;
     };
 
-    if (_item->_instruction == CSYNC_INSTRUCTION_CONFLICT
-        && _item->_size == _item->_previousSize
-        && !_item->_checksumHeader.isEmpty()
-        && (csync_is_collision_safe_hash(_item->_checksumHeader)
-            || _item->_modtime == _item->_previousModtime)) {
+    if (_item->instruction() == CSYNC_INSTRUCTION_CONFLICT && _item->_size == _item->_previousSize && !_item->_checksumHeader.isEmpty()
+        && (csync_is_collision_safe_hash(_item->_checksumHeader) || _item->_modtime == _item->_previousModtime)) {
         qCDebug(lcPropagateDownload) << _item->_file << "may not need download, computing checksum";
         auto computeChecksum = new ComputeChecksum(this);
         const auto checksumHeader = ChecksumHeader::parseChecksumHeader(_item->_checksumHeader);
@@ -517,7 +522,6 @@ void PropagateDownloadFile::conflictChecksumComputed(CheckSums::Algorithm checks
         auto fn = propagator()->fullLocalPath(_item->_file);
         if (_item->_modtime != _item->_previousModtime) {
             FileSystem::setModTime(fn, _item->_modtime);
-            emit propagator()->touchedFile(fn);
         }
         _item->_modtime = FileSystem::getModTime(fn);
         updateMetadata(/*isConflict=*/false);
@@ -770,9 +774,7 @@ void PropagateDownloadFile::slotGetFinished()
     // but not for HTTP2 or SPDY replies. For these it remains and contains the size
     // of the compressed data. See QTBUG-73364.
     const auto contentEncoding = job->reply()->rawHeader("content-encoding").toLower();
-    if ((contentEncoding == "gzip" || contentEncoding == "deflate")
-        && (job->reply()->attribute(QNetworkRequest::Http2WasUsedAttribute).toBool()
-            || job->reply()->attribute(QNetworkRequest::SpdyWasUsedAttribute).toBool())) {
+    if ((contentEncoding == "gzip" || contentEncoding == "deflate") && (job->reply()->attribute(QNetworkRequest::Http2WasUsedAttribute).toBool())) {
         bodySize = 0;
         hasSizeHeader = false;
     }
@@ -854,6 +856,7 @@ void PropagateDownloadFile::deleteExistingFolder()
     // Delete the directory if it is empty!
     QDir dir(existingDir);
     if (dir.entryList(QDir::NoDotAndDotDot | QDir::AllEntries).count() == 0) {
+        qCDebug(lcPropagateDownload) << "deleting existing dir" << existingDir << "to replace it with a file";
         if (dir.rmdir(existingDir)) {
             return;
         }
@@ -931,8 +934,7 @@ void PropagateDownloadFile::downloadFinished()
         }
     }
 
-    bool isConflict = _item->_instruction == CSYNC_INSTRUCTION_CONFLICT
-        && (QFileInfo(fn).isDir() || !FileSystem::fileEquals(fn, _tmpFile.fileName()));
+    bool isConflict = _item->instruction() == CSYNC_INSTRUCTION_CONFLICT && (QFileInfo(fn).isDir() || !FileSystem::fileEquals(fn, _tmpFile.fileName()));
     if (isConflict) {
         QString error;
         if (!propagator()->createConflict(_item, _associatedComposite, &error)) {
@@ -949,7 +951,7 @@ void PropagateDownloadFile::downloadFinished()
         // the discovery phase and now.
         const qint64 expectedSize = _item->_previousSize;
         const time_t expectedMtime = _item->_previousModtime;
-        if (FileSystem::fileChanged(fn, expectedSize, expectedMtime)) {
+        if (FileSystem::fileChanged(QFileInfo{fn}, expectedSize, expectedMtime)) {
             propagator()->_anotherSyncNeeded = true;
             done(SyncFileItem::SoftError, tr("File has changed since discovery"));
             return;
@@ -964,7 +966,6 @@ void PropagateDownloadFile::downloadFinished()
     }
 
     QString error;
-    emit propagator()->touchedFile(fn);
     // The fileChanged() check is done above to generate better error messages.
     if (!FileSystem::uncheckedRenameReplace(_tmpFile.fileName(), fn, &error)) {
         qCWarning(lcPropagateDownload) << "Rename failed:" << _tmpFile.fileName() << "=>" << fn << "with error:" << error;
@@ -977,7 +978,7 @@ void PropagateDownloadFile::downloadFinished()
 
     // Maybe we downloaded a newer version of the file than we thought we would...
     // Get up to date information for the journal.
-    _item->_size = FileSystem::getSize(fn);
+    _item->_size = FileSystem::getSize(QFileInfo{fn});
 
     // Maybe what we downloaded was a conflict file? If so, set a conflict record.
     // (the data was prepared in slotGetFinished above)
@@ -1003,15 +1004,16 @@ void PropagateDownloadFile::downloadFinished()
             // Move the pin state to the new location
             auto pin = propagator()->_journal->internalPinStates().rawForPath(virtualFile.toUtf8());
             if (pin && *pin != PinState::Inherited) {
-                vfs->setPinState(_item->_file, *pin);
-                vfs->setPinState(virtualFile, PinState::Inherited);
+                std::ignore = vfs->setPinState(_item->_file, *pin);
+                std::ignore = vfs->setPinState(virtualFile, PinState::Inherited);
             }
         }
 
         // Ensure the pin state isn't contradictory
         auto pin = vfs->pinState(_item->_file);
-        if (pin && *pin == PinState::OnlineOnly)
-            vfs->setPinState(_item->_file, PinState::Unspecified);
+        if (pin && *pin == PinState::OnlineOnly) {
+            std::ignore = vfs->setPinState(_item->_file, PinState::Unspecified);
+        }
     }
 
     updateMetadata(isConflict);
